@@ -8,11 +8,11 @@
 
 /* .Fortran calls */
 extern void F77_NAME(draw_ju)(void *, void *, void *, void *, void *);
-extern void F77_NAME(estimate_bct_ordinal)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
+extern void F77_NAME(estimate_bct_ordinal)(void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *, void *);
 
 static const R_FortranMethodDef FortranEntries[] = {
     {"draw_ju",              (DL_FUNC) &F77_NAME(draw_ju), 5},
-    {"estimate_bct_ordinal", (DL_FUNC) &F77_NAME(estimate_bct_ordinal), 28},
+    {"estimate_bct_ordinal", (DL_FUNC) &F77_NAME(estimate_bct_ordinal), 29},
     {NULL, NULL, 0}
 };
 
